SvgPathData class

A single parsed SVG path element.

Constructors

SvgPathData({required String id, required String pathData})
Creates an SvgPathData.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The id attribute of the path element.
final
pathData String
The raw "d" attribute string of the path element.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited